@@ -18,6 +18,7 @@ topic_list_str_pub = ''
 topic_list_str_sub = ''
 isReconnect = False
 mqtt_thread = None
+heart_beat_time = 5
 
 
 def setServerUrl(url='127.0.0.1', port=1883, clientID=str(int(time.time() * 1000))):
@@ -27,6 +28,11 @@ def setServerUrl(url='127.0.0.1', port=1883, clientID=str(int(time.time() * 1000
     client_id = clientID
 
 
+def setHeartBeatTime(heart_time=5):
+    global heart_beat_time
+    heart_beat_time = heart_time
+
+
 def setMqttLog(PrintLog=False):
     global isPrintLog
     isPrintLog = PrintLog
@@ -81,7 +87,7 @@ def on_message(client, obj, msg):
                         break
             if isThisTopic:
                 # threading.Thread(target=callback, args=(item, msg, client), daemon=True).start()
-                callback(item, msg, client)
+                callback(item, msg, topic)
                 break
 
 
@@ -91,14 +97,27 @@ def callback(topic, msg, client):
     if type(msg) is str:
         msg = json.loads(msg)
     if topic not in callback_dit:
-        callback_dit[topic] = {'func': None, 'cond': threading.Event(), 'msg': None}
+        isTongPei = False
+        keys = callback_dit.keys()
+        for item in keys:
+            if "+" in item:
+                item_arr = item.split("/")[1:]
+                topic_arr = topic.split("/")[1:]
+                if item_arr[0] == topic_arr[0]:
+                    isTongPei = True
+                    break
+        if not isTongPei:
+            callback_dit[topic] = {'func': None, 'cond': threading.Event(), 'msg': None}
     callback_dit[topic]['msg'] = msg
     cond = get_cond(topic)
     cond.set()
     cond.clear()
     if callback_dit[topic]['func'] is not None:
         func = callback_dit[topic]['func']
-        func(msg, topic)
+        if '+' in topic:
+            func(msg, client)
+        else:
+            func(msg, topic)
 
 
 # 一旦订阅成功，回调此方法
@@ -134,7 +153,7 @@ def Mqtt():
             mqttc.on_disconnect = on_disconnect
             mqttc.on_log = on_log
             # 连接broker，心跳时间为60s
-            mqttc.connect(server_url, server_port, 5)
+            mqttc.connect(server_url, server_port, heart_beat_time)
             # 订阅该主题，QoS=0
             mqtt_thread = threading.Thread(target=mqttc.loop_forever, daemon=True)
             mqtt_thread.start()
